Nikolay Sivov : dbgeng: Added DebugCreateEx() stub.

Alexandre Julliard julliard at winehq.org
Wed Sep 6 14:45:36 CDT 2017


Module: wine
Branch: master
Commit: 0d078dbc82208caef06273c51e46faabc5452828
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=0d078dbc82208caef06273c51e46faabc5452828

Author: Nikolay Sivov <nsivov at codeweavers.com>
Date:   Wed Sep  6 12:19:30 2017 +0300

dbgeng: Added DebugCreateEx() stub.

Signed-off-by: Nikolay Sivov <nsivov at codeweavers.com>
Signed-off-by: Alexandre Julliard <julliard at winehq.org>

---

 dlls/dbgeng/dbgeng.c    | 18 ++++++++++++++----
 dlls/dbgeng/dbgeng.spec |  2 +-
 2 files changed, 15 insertions(+), 5 deletions(-)

diff --git a/dlls/dbgeng/dbgeng.spec b/dlls/dbgeng/dbgeng.spec
index f2f735c..14dbc33 100644
--- a/dlls/dbgeng/dbgeng.spec
+++ b/dlls/dbgeng/dbgeng.spec
@@ -2,5 +2,5 @@
 @ stdcall DebugConnect(str ptr ptr)
 @ stub DebugConnectWide
 @ stdcall DebugCreate(ptr ptr)
-@ stub DebugCreateEx
+@ stdcall DebugCreateEx(ptr long ptr)
 @ stdcall DebugExtensionInitialize(ptr ptr)




More information about the wine-cvs mailing list
diff --git a/dlls/dbgeng/dbgeng.c b/dlls/dbgeng/dbgeng.c
index b08be75..6ac9360 100644
--- a/dlls/dbgeng/dbgeng.c
+++ b/dlls/dbgeng/dbgeng.c
@@ -58,8 +58,8 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 * Creating Debug Engine client object
 *
 * PARAMS
 *   InterfaceId   [I] Interface Id of debugger client
 *   pInterface    [O] Pointer to interface as requested via InterfaceId
 *
 * RETURNS
 *   Success: S_OK
@@ -68,9 +68,9 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 * BUGS
 *   Unimplemented
 */
-HRESULT WINAPI DebugCreate(REFIID InterfaceId, PVOID * pInterface)
+HRESULT WINAPI DebugCreate(REFIID riid, void **obj)
 {
-    FIXME("(%p,%p): stub\n", InterfaceId, pInterface);
+    FIXME("(%s, %p): stub\n", debugstr_guid(riid), obj);
 
     SetLastError(ERROR_CALL_NOT_IMPLEMENTED);
 
@@ -78,6 +78,16 @@ HRESULT WINAPI DebugCreate(REFIID InterfaceId, PVOID * pInterface)
 }
 
 /************************************************************
+*                    DebugCreateEx   (DBGENG.@)
+*/
+HRESULT WINAPI DebugCreateEx(REFIID riid, DWORD flags, void **obj)
+{
+    FIXME("(%s, %#x, %p): stub\n", debugstr_guid(riid), flags, obj);
+
+    return E_NOTIMPL;
+}
+
+/************************************************************
 *                    DebugConnect   (DBGENG.@)
 *
 * Creating Debug Engine client object and connecting it to remote host
@@ -58,8 +58,8 @@ HRESULT WINAPI DebugExtensionInitialize(ULONG * pVersion, ULONG * pFlags)
 *
 * PARAMS
-*   InterfaceId   [I] Interface Id of debugger client
-*   pInterface    [O] Pointer to interface as requested via InterfaceId
+*   riid   [I] Interface Id of debugger client
+*   obj    [O] Pointer to interface as requested via riid
 *
 * RETURNS